merge_roads: create a ring function

Description Usage Arguments Value Examples

View source: R/merge_roads.R

Description

create a ring function

Usage

1
merge_roads(inde_var, classvec, keep = F)

Arguments

inde_var

a dataframe with ROAD variables named 'ROAD', 5 types of roads, now is not a generic function, need the data to be formated in a way

classvec

the vectors of road types to merge, e.g. c(1,2,3) merges road type 1,2,3.

keep

indicate if the road types to be merged are to be kept, default is False, meaning not to keep them

Value

a data frame with merged road types

Examples

1
merge_roads(inde_var,c(1,2))

mengluchu/APMtools documentation built on Jan. 27, 2022, 2:41 a.m.