prediction_with_pp_La: Aggregate random forest using lasso

Description Usage Arguments

View source: R/prediction_with_pp_La.R

Description

Aggregate random forest using lasso

Usage

1
prediction_with_pp_La(rfmodel, trainingXY, trainingY, testingX)

Arguments

rfmodel

ranger model

trainingXY

training matrix, with same response and predictor names as in the rfmodel

trainingY

training response vection

testingX

testing matrix, with same response presented in the rfmodel


mengluchu/APMtools documentation built on Jan. 27, 2022, 2:41 a.m.