Description Usage Arguments Value
create a ring function
1 2 3 4 5 6 7 8 | create_ring(
inde_var,
normalize = F,
buffers_in = c(0, 25, 50, 100, 300, 500, 800, 1000, 3000),
buffers_out = c(25, 50, 100, 300, 500, 800, 1000, 3000, 5000),
number_roadtypes,
Road_varname = "ROAD"
)
|
inde_var |
a dataframe with ROAD variables named 'ROAD', n types of roads, now it is not a very generic function, need the data to be formated in a way as the buffers are ordered (e.g. 25m, 50m, 100m) |
normalize |
if T, devide the ring by the area of ring. Default is faulse |
buffers_in |
buffer sizes of the inner rings |
Road_varname |
the name of the road variable, grepl styple e.g. 'ROAD' |
buffer_out |
buufer sizes of the outter rings |
the road buffers becomes road ring buffers
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.