Description Usage Arguments Value Examples
create a ring function
1 | merge_roads(inde_var, classvec, keep = F)
|
inde_var |
a dataframe with ROAD variables named 'ROAD', 5 types of roads, now is not a generic function, need the data to be formated in a way |
classvec |
the vectors of road types to merge, e.g. c(1,2,3) merges road type 1,2,3. |
keep |
indicate if the road types to be merged are to be kept, default is False, meaning not to keep them |
a data frame with merged road types
1 | merge_roads(inde_var,c(1,2))
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.