View source: R/prediction_with_pp_La.R
Aggregate random forest using lasso
1 | prediction_with_pp_La(rfmodel, trainingXY, trainingY, testingX)
|
rfmodel |
ranger model |
trainingXY |
training matrix, with same response and predictor names as in the rfmodel |
trainingY |
training response vection |
testingX |
testing matrix, with same response presented in the rfmodel |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.